==> opensearch-dashboards-2.10.0p0.tgz: opensearch-dashboards/src/core/server/opensearch/client/scoped_cluster_client.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ScopedClusterClient = void 0;

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * Serves the same purpose as the normal {@link IClusterClient | cluster client} but exposes
 * an additional `asCurrentUser` method that doesn't use credentials of the OpenSearch Dashboards internal
 * user (as `asInternalUser` does) to request OpenSearch API, but rather passes HTTP headers
 * extracted from the current user request to the API instead.
 *
 * @public
 **/

/** @internal **/
class ScopedClusterClient {
  constructor(asInternalUser, asCurrentUser) {
    this.asInternalUser = asInternalUser;
    this.asCurrentUser = asCurrentUser;
  }

}

exports.ScopedClusterClient = ScopedClusterClient;

==> opensearch-dashboards-2.11.1.tgz: opensearch-dashboards/src/core/server/opensearch/client/scoped_cluster_client.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ScopedClusterClient = void 0;

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * Serves the same purpose as the normal {@link IClusterClient | cluster client} but exposes
 * an additional `asCurrentUser` method that doesn't use credentials of the OpenSearch Dashboards internal
 * user (as `asInternalUser` does) to request OpenSearch API, but rather passes HTTP headers
 * extracted from the current user request to the API instead.
 *
 * @public
 **/

/** @internal **/
class ScopedClusterClient {
  constructor(asInternalUser, asCurrentUser, asInternalUserWithLongNumeralsSupport, asCurrentUserWithLongNumeralsSupport) {
    this.asInternalUser = asInternalUser;
    this.asCurrentUser = asCurrentUser;
    this.asInternalUserWithLongNumeralsSupport = asInternalUserWithLongNumeralsSupport;
    this.asCurrentUserWithLongNumeralsSupport = asCurrentUserWithLongNumeralsSupport;
  }

}

exports.ScopedClusterClient = ScopedClusterClient;
